summaryrefslogtreecommitdiffstats
path: root/src/testlib
diff options
context:
space:
mode:
authorQt Forward Merge Bot <qt_forward_merge_bot@qt-project.org>2018-02-28 10:32:56 +0100
committerQt Forward Merge Bot <qt_forward_merge_bot@qt-project.org>2018-02-28 10:32:56 +0100
commit96ffe48add521e29d883814a35b1130b9dfdd636 (patch)
treed0ae779efa69ecb8c39999786af22152db902806 /src/testlib
parent37217c57fa5595e7cdfd7e19f34de22848dfc370 (diff)
parenteba652a99f602386127e552740fddf5445b3d7c9 (diff)
Merge remote-tracking branch 'origin/5.11' into dev
Diffstat (limited to 'src/testlib')
-rw-r--r--src/testlib/qtestsystem.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/testlib/qtestsystem.h b/src/testlib/qtestsystem.h
index de6bd177d3..a6cea26884 100644
--- a/src/testlib/qtestsystem.h
+++ b/src/testlib/qtestsystem.h
@@ -112,7 +112,7 @@ namespace QTest
{
bool becameActive = qWaitFor([&]() { return window->isActive(); }, timeout);
// Try ensuring the platform window receives the real position.
// (i.e. that window->pos() reflects reality)
// isActive() ( == FocusIn in case of X) does not guarantee this. It seems some WMs randomly
// send the final ConfigureNotify (the one with the non-bogus 0,0 position) after the FocusIn.
@@ -120,7 +120,7 @@ namespace QTest
// qWaitForWindowShown() will generate bogus results.
if (becameActive) {
int waitNo = 0; // 0, 0 might be a valid position after all, so do not wait for ever
- while (window->position().isNull()) {
+ while (window->frameGeometry().isNull()) {
if (waitNo++ > timeout / 10)
break;
qWait(10);
@@ -112,7 +112,7 @@ namespace QTest
{
bool becameActive = qWaitFor([&]() { return window->isActive(); }, timeout);
- // Try ensuring the platform window receives the real position.
+ // Try ensuring the platform window receives the real position and geometry.
// (i.e. that window->pos() reflects reality)
// isActive() ( == FocusIn in case of X) does not guarantee this. It seems some WMs randomly